@@ -37,11 +37,11 @@ App::GitHooks - Extensible plugins system for git hooks.
 
 =head1 VERSION
 
-Version 1.3.0
+Version 1.4.0
 
 =cut
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.0';
 
 
 =head1 DESCRIPTION
@@ -267,18 +267,37 @@ C<[section_1]> section).
 =head2 Configuration file locations
 
 L<App::GitHooks> supports setting custom options by creating one of the
-following files:
+following files, which are searched in descending order of preference:
 
 =over 4
 
 =item *
 
+A file of any name anywhere on your system, if you set the environment variable
+C<GITHOOKSRC_FORCE> to its path.
+
+Note that you should normally use C<GITHOOKSRC>. This option is provided mostly
+for testing purposes, when configuration options for testing in a reliable
+manner are of the utmost importance and take precedence over any
+repository-specific settings.
+
+=item *
+
 A C<.githooksrc> file at the root of the git repository.
 
 The settings will then only apply to that repository.
 
 =item *
 
+A file of any name anywhere on your system, if you set the environment variable
+C<GITHOOKSRC> to its path.
+
+Note that C<.githooksrc> files at the top of a repository or in a user's home
+directory will take precedence over a file specified by the C<GITHOOKSRC>
+environment variable.
+
+=item *
+
 A C<.githooksrc> file in the home directory of the current user.
 
 The settings will then apply to all the repositories that have hooks set up.
@@ -288,14 +307,6 @@ directory of the current user (as it is presumably more specific). Auto-merge
 of options across multiple C<.githooksrc> files in an inheritance fashion is
 not currently supported.
 
-=item *
-
-A file of any name anywhere on your system, if you set the environment variable C<GITHOOKSRC> to its path.
-
-Note that C<.githooksrc> files at the top of a repository or in a user's home
-directory will take precedence over a file specified by the C<GITHOOKSRC>
-environment variable.
-
 =back
 
 
@@ -341,6 +352,15 @@ analyzing files as part of file-level checks.
 
 	skip_directories = /^cpan(?:-[^\/]+)?\//
 
+=item * force_plugins
+
+A comma-separated list of the plugins that must be present on the system and
+will be executed. If any plugins from this list are missing, the action will
+error out. If any other plugins not in this list are installed on the system,
+they will be ignored.
+
+	force_plugins = App::GitHooks::Plugin::ValidatePODFormat, App::GitHooks::Plugin::RequireCommitMessage
+
 =back
 
 
@@ -350,7 +370,7 @@ analyzing files as part of file-level checks.
 
 =item * limit_plugins
 
-A comma-separated list of the only plugins that will be executed during tests.
+Deprecated. Use C<force_plugins> instead.
 
 =item * force_interactive
 
@@ -648,28 +668,54 @@ Return a hashref of the plugins available for every git hook.
 sub get_all_plugins
 {
 	my ( $self ) = @_;
+	my $config = $self->get_config();
 
 	# Find all available plugins regardless of the desired target hook, using
 	# Module::Pluggable.
 	my @discovered_plugins = __PACKAGE__->_search_plugins();
 
+	# Warn about deprecated 'limit_plugins' config option.
+	my $limit_plugins = $config->get( 'testing', 'limit_plugins' );
+	if ( defined( $limit_plugins ) )
+	{
+		carp "The configuration option 'limit_plugins' under the [testing] section "
+			. "is deprecated, please switch to using 'force_plugins' under the general "
+			. "configuration section as soon as possible";
+	}
+
 	# If the environment restricts the list of plugins to run, we use that.
 	# Otherwise, we exclude test plugins.
+	my $force_plugins = $config->get( '_', 'force_plugins' )
+		// $limit_plugins
+		// '';
 	my @plugins = ();
-	my $config = $self->get_config();
-	my $limit_plugins = $config->get( 'testing', 'limit_plugins' ) // '';
-	if ( $limit_plugins =~ /\w/ )
+	if ( $force_plugins =~ /\w/ )
 	{
-		my %allowed_plugins =
+		my %forced_plugins =
 			map { $_ => 1 }
-			split( /(?:\s+|\s*,\s*)/, $limit_plugins );
+			# Prepend App::GitHooks::Plugin:: to the plugin name if omitted.
+			map { $_ =~ /^App/ ? $_ : "App::GitHooks::Plugin::$_" }
+			# Split the comma-separated list.
+			split( /(?:\s+|\s*,\s*)/, $force_plugins );
 
 		foreach my $plugin ( @discovered_plugins )
 		{
-			next if !$allowed_plugins{ $plugin };
+			# Only add plugins listed in the config file.
+			next if !$forced_plugins{ $plugin };
 
 			push( @plugins, $plugin );
-			delete( $allowed_plugins{ $plugin } );
+			delete( $forced_plugins{ $plugin } );
+		}
+
+		# If plugins listed in the config file are not found on the system, don't
+		# continue.
+		if ( scalar( keys %forced_plugins ) != 0 )
+		{
+			croak sprintf(
+				"The following plugins must be installed on your system, per the "
+				. "'force_plugins' directive in your githooksrc config file: %s",
+				join( ', ', keys %forced_plugins ),
+			);
 		}
 	}
 	else
@@ -725,26 +771,37 @@ sub get_config
 	if ( !defined( $self->{'config'} ) )
 	{
 		my $config_file;
-		# First, use repository-specific githooksrc files.
-		if ( -e '.githooksrc' )
+		my $config_source;
+		# For testing purposes, provide a way to enforce a specific .githooksrc
+		# file regardless of how anything else is set up on the machine.
+		if ( defined( $ENV{'GITHOOKSRC_FORCE'} ) && ( -e $ENV{'GITHOOKSRC_FORCE'} ) )
 		{
+			$config_source = 'GITHOOKSRC_FORCE environment variable';
+			$config_file = $ENV{'GITHOOKSRC_FORCE'};
+		}
+		# First, use repository-specific githooksrc files.
+		elsif ( -e '.githooksrc' )
+		{
+			$config_source = '.githooksrc at the root of the repository';
 			$config_file = '.githooksrc';
 		}
 		# Fall back on the GITHOOKSRC variable.
 		elsif ( defined( $ENV{'GITHOOKSRC'} ) && ( -e $ENV{'GITHOOKSRC'} ) )
 		{
+			$config_source = 'GITHOOKSRC environment variable';
 			$config_file = $ENV{'GITHOOKSRC'};
 		}
 		# Fall back on the home directory of the user.
 		elsif ( defined( $ENV{'HOME'} ) && ( -e $ENV{'HOME'} . '/.githooksrc' ) )
 		{
+			$config_source = '.githooksrc in the home directory';
 			$config_file = $ENV{'HOME'} . '/.githooksrc';
 		}
 
 		$self->{'config'} = App::GitHooks::Config->new(
 			defined( $config_file )
-				? ( file => $config_file )
-				: ()
+				? ( file => $config_file, source => $config_source )
+				: (),
 		);
 	}
 
