@@ -15,11 +15,11 @@ App::GitHooks::Config - Configuration manager for App::GitHooks.
 
 =head1 VERSION
 
-Version 1.3.0
+Version 1.4.0
 
 =cut
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.0';
 
 
 =head1 SYNOPSIS
@@ -47,9 +47,13 @@ Arguments:
 
 =over 4
 
-=item * file
+=item * file I<(optional)>
 
-An optional path to a config file to load into the object.
+A path to a config file to load into the object.
+
+=item * source I<(optional)>
+
+How the path of the config file to use was determined.
 
 =back
 
@@ -59,6 +63,7 @@ sub new
 {
 	my ( $class, %args ) = @_;
 	my $file = delete( $args{'file'} );
+	my $source = delete( $args{'source'} );
 
 	my $self = defined( $file )
 		? Config::Tiny->read( $file )
@@ -66,6 +71,10 @@ sub new
 
 	bless( $self, $class );
 
+	# Store meta-information for future reference.
+	$self->{'__source'} = $source;
+	$self->{'__path'} = $file;
+
 	return $self;
 }
 
